==> duckscript-0.8.7.tar.gz: duckscript-0.8.7/duckscript_sdk/src/sdk/std/semver/is_newer/mod.rs <==
use crate::utils::pckg;
use duckscript::types::command::{Command, CommandResult};
use semver::Version;

#[cfg(test)]
#[path = "./mod_test.rs"]
mod mod_test;

#[derive(Clone)]
pub(crate) struct CommandImpl {
    package: String,
}

impl Command for CommandImpl {
    fn name(&self) -> String {
        pckg::concat(&self.package, "IsNewer")
    }

    fn aliases(&self) -> Vec<String> {
        vec!["semver_is_newer".to_string()]
    }

    fn help(&self) -> String {
        include_str!("help.md").to_string()
    }

    fn clone_and_box(&self) -> Box<dyn Command> {
        Box::new((*self).clone())
    }

    fn run(&self, arguments: Vec<String>) -> CommandResult {
        if arguments.len() < 2 {
            CommandResult::Error("Missing semver values to compare.".to_string())
        } else {
            match Version::parse(&arguments[0]) {
                Ok(newer_version) => match Version::parse(&arguments[1]) {
                    Ok(older_version) => {
                        let result = if newer_version > older_version {
                            true
                        } else {
                            false
                        };

                        CommandResult::Continue(Some(result.to_string()))
                    }
                    Err(error) => CommandResult::Error(error.to_string()),
                },
                Err(error) => CommandResult::Error(error.to_string()),
            }
        }
    }
}

pub(crate) fn create(package: &str) -> Box<dyn Command> {
    Box::new(CommandImpl {
        package: package.to_string(),
    })
}

==> duckscript-0.11.1.tar.gz: duckscript-0.11.1/duckscript_sdk/src/sdk/std/semver/is_newer/mod.rs <==
use crate::utils::pckg;
use duckscript::types::command::{Command, CommandInvocationContext, CommandResult};
use semver::Version;

#[cfg(test)]
#[path = "./mod_test.rs"]
mod mod_test;

#[derive(Clone)]
pub(crate) struct CommandImpl {
    package: String,
}

impl Command for CommandImpl {
    fn name(&self) -> String {
        pckg::concat(&self.package, "IsNewer")
    }

    fn aliases(&self) -> Vec<String> {
        vec!["semver_is_newer".to_string()]
    }

    fn help(&self) -> String {
        include_str!("help.md").to_string()
    }

    fn clone_and_box(&self) -> Box<dyn Command> {
        Box::new((*self).clone())
    }

    fn run(&self, context: CommandInvocationContext) -> CommandResult {
        if context.arguments.len() < 2 {
            CommandResult::Error("Missing semver values to compare.".to_string())
        } else {
            match Version::parse(&context.arguments[0]) {
                Ok(newer_version) => match Version::parse(&context.arguments[1]) {
                    Ok(older_version) => {
                        let result = if newer_version > older_version {
                            true
                        } else {
                            false
                        };

                        CommandResult::Continue(Some(result.to_string()))
                    }
                    Err(error) => CommandResult::Error(error.to_string()),
                },
                Err(error) => CommandResult::Error(error.to_string()),
            }
        }
    }
}

pub(crate) fn create(package: &str) -> Box<dyn Command> {
    Box::new(CommandImpl {
        package: package.to_string(),
    })
}
